Function libvnc_sys::rfb::HandleCursorShape

source ·
pub unsafe extern "C" fn HandleCursorShape(
    client: *mut rfbClient,
    xhot: c_int,
    yhot: c_int,
    width: c_int,
    height: c_int,
    enc: u32
) -> rfbBool
Handles XCursor and RichCursor shape updates from the server. We emulate cursor operating on the frame buffer (that is why we call it “software cursor”). This decodes the received cursor shape and hands it over to GotCursorShapeProc, if set.