Function libvnc_sys::rfb::HandleRFBServerMessage

source ·
pub unsafe extern "C" fn HandleRFBServerMessage(
    client: *mut rfbClient
) -> rfbBool
Handles messages from the RFB server. You must call this function intermittently so LibVNCClient can parse messages from the server. For example, if your app has a draw loop, you could place a call to this function within that draw loop. @note You must call WaitForMessage() before you call this function. @param client The client which will handle the RFB server messages @return true if the client was able to handle the RFB server messages, false otherwise