Function libvnc_sys::rfb::SendClientCutText

source ·
pub unsafe extern "C" fn SendClientCutText(
    client: *mut rfbClient,
    str_: *mut c_char,
    len: c_int
) -> rfbBool
Places a string on the server’s clipboard. Use this function if you want to be able to copy and paste between the server and your application. For instance, when your application is notified that the user copied some text onto the clipboard, you would call this function to synchronize the server’s clipboard with your local clipboard. @param client The client structure through which to send the client cut text message @param str The string to send (doesn’t need to be NULL terminated) @param len The length of the string @return true if the client cut message was sent successfully, false otherwise