Function libvnc_sys::rfb::SendFramebufferUpdateRequest
source · pub unsafe extern "C" fn SendFramebufferUpdateRequest(
client: *mut rfbClient,
x: c_int,
y: c_int,
w: c_int,
h: c_int,
incremental: rfbBool
) -> rfbBoolExpand description
Sends a framebuffer update request to the server. A VNC client may request an update from the server at any time. You can also specify which portions of the screen you want updated. This can be handy if a pointer is at certain location and the user pressed a mouse button, for instance. Then you can immediately request an update of the region around the pointer from the server. @note The coordinate system is a left-handed Cartesian coordinate system with the Z axis (unused) pointing out of the screen. Alternately you can think of it as a right-handed Cartesian coordinate system with the Z axis pointing into the screen. The origin is at the upper left corner of the framebuffer. @param client The client through which to send the request @param x The horizontal position of the update request rectangle @param y The vertical position of the update request rectangle @param w The width of the update request rectangle @param h The height of the update request rectangle @param incremental false: server sends rectangle even if nothing changed. true: server only sends changed parts of rectangle. @return true if the update request was sent successfully, false otherwise