Function libvnc_sys::rfb::SendPointerEvent
source · pub unsafe extern "C" fn SendPointerEvent(
client: *mut rfbClient,
x: c_int,
y: c_int,
buttonMask: c_int
) -> rfbBoolExpand description
Sends a pointer event to the server. A pointer event includes a cursor location and a button mask. The button mask indicates which buttons on the pointing device are pressed. Each button is represented by a bit in the button mask. A 1 indicates the button is pressed while a 0 indicates that it is not pressed. You may use these pre-defined button masks by ORing them together: rfbButton1Mask, rfbButton2Mask, rfbButton3Mask, rfbButton4Mask rfbButton5Mask @note The cursor location is relative to the client’s framebuffer, not the client’s screen itself. @note The coordinate system is a left-handed Cartesian coordinate system with the Z axis (unused) pointing out of the screen. Alternately you can think of it as a right-handed Cartesian coordinate system with the Z axis pointing into the screen. The origin is at the upper left corner of the screen. @param client The client through which to send the pointer event @param x the horizontal location of the cursor @param y the vertical location of the cursor @param buttonMask the button mask indicating which buttons are pressed @return true if the pointer event was sent successfully, false otherwise