Function libvnc_sys::rfb::SetFormatAndEncodings

source ·
pub unsafe extern "C" fn SetFormatAndEncodings(
    client: *mut rfbClient
) -> rfbBool
Sends format and encoding parameters to the server. Your application can modify the ‘client’ data structure directly. However some changes to this structure must be communicated back to the server. For instance, if you change the encoding to hextile, the server needs to know that it should send framebuffer updates in hextile format. Likewise if you change the pixel format of the framebuffer, the server must be notified about this as well. Call this function to propagate your changes of the local ‘client’ structure over to the server. @li Encoding type @li RFB protocol extensions announced via pseudo-encodings @li Framebuffer pixel format (like RGB vs ARGB) @li Remote cursor support @param client The client in which the format or encodings have been changed @return true if the format or encodings were sent to the server successfully, false otherwise