Function libvnc_sys::rfb::TextChatClose

source ·
pub unsafe extern "C" fn TextChatClose(
    client: *mut rfbClient
) -> rfbBool
Closes the text chat window on the server. @param client The client through which to send the message @return true if the window was closed successfully, false otherwise