Function libvnc_sys::rfb::WaitForMessage

source ·
pub unsafe extern "C" fn WaitForMessage(
    client: *mut rfbClient,
    usecs: c_uint
) -> c_int
Waits for an RFB message to arrive from the server. Before handling a message with HandleRFBServerMessage(), you must wait for your client to receive one. This function blocks until a message is received. You may specify a timeout in microseconds. Once this number of microseconds have elapsed, the function will return. @param client The client to cause to wait until a message is received @param usecs The timeout in microseconds @return the return value of the underlying select() call