Function libvnc_sys::rfb::rfbClientSetClientData

source ·
pub unsafe extern "C" fn rfbClientSetClientData(
    client: *mut rfbClient,
    tag: *mut c_void,
    data: *mut c_void
)
Associates a client data tag with the given pointer. LibVNCClient has several events to which you can associate your own handlers. These handlers have the client structure as one of their parameters. Sometimes, you may want to make data from elsewhere in your application available to these handlers without using a global variable. To do this, you call rfbClientSetClientData() and associate the data with a tag. Then, your handler can call rfbClientGetClientData() and get the a pointer to the data associated with that tag. @param client The client in which to set the client data @param tag A unique tag which identifies the data @param data A pointer to the data to associate with the tag