Struct libvnc_sys::rfb::_rfbClient

source ·
#[repr(C)]
pub struct _rfbClient {
Show 94 fields pub frameBuffer: *mut u8, pub width: c_int, pub height: c_int, pub endianTest: c_int, pub appData: AppData, pub programName: *const c_char, pub serverHost: *mut c_char, pub serverPort: c_int, pub listenSpecified: rfbBool, pub listenPort: c_int, pub flashPort: c_int, pub updateRect: _rfbClient__bindgen_ty_1, pub buffer: [c_char; 307200], pub sock: c_int, pub canUseCoRRE: rfbBool, pub canUseHextile: rfbBool, pub desktopName: *mut c_char, pub format: rfbPixelFormat, pub si: rfbServerInitMsg, pub buf: [c_char; 8192], pub bufoutptr: *mut c_char, pub buffered: c_uint, pub ultra_buffer_size: c_int, pub ultra_buffer: *mut c_char, pub raw_buffer_size: c_int, pub raw_buffer: *mut c_char, pub decompStream: z_stream, pub decompStreamInited: rfbBool, pub zlib_buffer: [c_char; 30000], pub zlibStream: [z_stream; 4], pub zlibStreamActive: [rfbBool; 4], pub cutZeros: rfbBool, pub rectWidth: c_int, pub rectColors: c_int, pub tightPalette: [c_char; 1024], pub tightPrevRow: [u8; 12288], pub jpegError: rfbBool, pub jpegSrcManager: *mut jpeg_source_mgr, pub jpegBufferPtr: *mut c_void, pub jpegBufferLen: usize, pub rcSource: *mut u8, pub rcMask: *mut u8, pub clientData: *mut rfbClientData, pub vncRec: *mut rfbVNCRec, pub KeyboardLedStateEnabled: c_int, pub CurrentKeyboardLedState: c_int, pub canHandleNewFBSize: c_int, pub HandleTextChat: HandleTextChatProc, pub HandleKeyboardLedState: HandleKeyboardLedStateProc, pub HandleCursorPos: HandleCursorPosProc, pub SoftCursorLockArea: SoftCursorLockAreaProc, pub SoftCursorUnlockScreen: SoftCursorUnlockScreenProc, pub GotFrameBufferUpdate: GotFrameBufferUpdateProc, pub GetPassword: GetPasswordProc, pub MallocFrameBuffer: MallocFrameBufferProc, pub GotXCutText: GotXCutTextProc, pub Bell: BellProc, pub GotCursorShape: GotCursorShapeProc, pub GotCopyRect: GotCopyRectProc, pub supportedMessages: rfbSupportedMessages, pub major: c_int, pub minor: c_int, pub authScheme: u32, pub subAuthScheme: u32, pub tlsSession: *mut c_void, pub GetCredential: GetCredentialProc, pub clientAuthSchemes: *mut u32, pub destHost: *mut c_char, pub destPort: c_int, pub QoS_DSCP: c_int, pub HandleXvpMsg: HandleXvpMsgProc, pub listenSock: c_int, pub FinishedFrameBufferUpdate: FinishedFrameBufferUpdateProc, pub listenAddress: *mut c_char, pub listen6Sock: c_int, pub listen6Address: *mut c_char, pub listen6Port: c_int, pub outputWindow: c_ulong, pub LockWriteToTLS: LockWriteToTLSProc, pub UnlockWriteToTLS: UnlockWriteToTLSProc, pub GotFillRect: GotFillRectProc, pub GotBitmap: GotBitmapProc, pub GotJpeg: GotJpegProc, pub saslconn: *mut sasl_conn_t, pub saslDecoded: *const c_char, pub saslDecodedLength: c_uint, pub saslDecodedOffset: c_uint, pub saslSecret: *mut sasl_secret_t, pub GetSASLMechanism: GetSASLMechanismProc, pub GetUser: GetUserProc, pub tjhnd: *mut c_void, pub connectTimeout: c_uint, pub readTimeout: c_uint, pub tlsRwMutex: pthread_mutex_t,
}

Fields

frameBuffer: *mut u8width: c_intheight: c_intendianTest: c_intappData: AppDataprogramName: *const c_charserverHost: *mut c_charserverPort: c_int

< if -1, then use file recorded by vncrec

listenSpecified: rfbBoollistenPort: c_intflashPort: c_intupdateRect: _rfbClient__bindgen_ty_1buffer: [c_char; 307200]sock: c_intcanUseCoRRE: rfbBoolcanUseHextile: rfbBooldesktopName: *mut c_charformat: rfbPixelFormatsi: rfbServerInitMsgbuf: [c_char; 8192]bufoutptr: *mut c_charbuffered: c_uintultra_buffer_size: c_intultra_buffer: *mut c_charraw_buffer_size: c_intraw_buffer: *mut c_chardecompStream: z_streamdecompStreamInited: rfbBoolzlib_buffer: [c_char; 30000]zlibStream: [z_stream; 4]zlibStreamActive: [rfbBool; 4]cutZeros: rfbBoolrectWidth: c_intrectColors: c_inttightPalette: [c_char; 1024]tightPrevRow: [u8; 12288]jpegError: rfbBool

JPEG decoder state (obsolete– do not use).

jpegSrcManager: *mut jpeg_source_mgrjpegBufferPtr: *mut c_voidjpegBufferLen: usizercSource: *mut u8

Holds cursor shape data when received from server.

rcMask: *mut u8

Holds cursor shape data when received from server.

clientData: *mut rfbClientData

private data pointer

vncRec: *mut rfbVNCRecKeyboardLedStateEnabled: c_intCurrentKeyboardLedState: c_intcanHandleNewFBSize: c_intHandleTextChat: HandleTextChatProcHandleKeyboardLedState: HandleKeyboardLedStateProcHandleCursorPos: HandleCursorPosProcSoftCursorLockArea: SoftCursorLockAreaProcSoftCursorUnlockScreen: SoftCursorUnlockScreenProcGotFrameBufferUpdate: GotFrameBufferUpdateProcGetPassword: GetPasswordProc

the pointer returned by GetPassword will be freed after use!

MallocFrameBuffer: MallocFrameBufferProcGotXCutText: GotXCutTextProcBell: BellProcGotCursorShape: GotCursorShapeProcGotCopyRect: GotCopyRectProcsupportedMessages: rfbSupportedMessages

Which messages are supported by the server This is a guess for most servers. (If we can even detect the type of server)

If the server supports the “rfbEncodingSupportedMessages” then this will be updated when the encoding is received to accurately reflect the servers capabilities.

major: c_int

negotiated protocol version

minor: c_int

negotiated protocol version

authScheme: u32

The selected security types

subAuthScheme: u32

The selected security types

tlsSession: *mut c_void

The TLS session for Anonymous TLS and VeNCrypt

GetCredential: GetCredentialProc

To support security types that requires user input (except VNC password authentication), for example VeNCrypt and MSLogon, this callback function must be set before the authentication. Otherwise, it implicates that the caller application does not support it and related security types should be bypassed.

clientAuthSchemes: *mut u32

The 0-terminated security types supported by the client. Set by function SetClientAuthSchemes()

destHost: *mut c_char

When the server is a repeater, this specifies the final destination

destPort: c_intQoS_DSCP: c_int

the QoS IP DSCP for this client

HandleXvpMsg: HandleXvpMsgProc

hook to handle xvp server messages

listenSock: c_intFinishedFrameBufferUpdate: FinishedFrameBufferUpdateProclistenAddress: *mut c_charlisten6Sock: c_intlisten6Address: *mut c_charlisten6Port: c_intoutputWindow: c_ulongLockWriteToTLS: LockWriteToTLSProc

These lock/unlock hooks are not used anymore. LibVNCClient will now use platform-specific synchronization library to protect concurrent TLS R/W.

@deprecated

UnlockWriteToTLS: UnlockWriteToTLSProcGotFillRect: GotFillRectProc

Hooks for custom rendering

VNC rendering boils down to 3 activities:

  • GotCopyRect: copy an area of the framebuffer
  • GotFillRect: fill an area of the framebuffer with a solid color
  • GotBitmap: copy the bitmap in the buffer into the framebuffer The client application should either set all three of these or none!
GotBitmap: GotBitmapProcGotJpeg: GotJpegProc

Hook for custom JPEG decoding and rendering

saslconn: *mut sasl_conn_tsaslDecoded: *const c_charsaslDecodedLength: c_uintsaslDecodedOffset: c_uintsaslSecret: *mut sasl_secret_tGetSASLMechanism: GetSASLMechanismProcGetUser: GetUserProctjhnd: *mut c_void

JPEG decoder state.

connectTimeout: c_uintreadTimeout: c_uinttlsRwMutex: pthread_mutex_t