Struct libvnc_sys::rfb::_rfbProtocolExtension
source · #[repr(C)]pub struct _rfbProtocolExtension {
pub newClient: Option<unsafe extern "C" fn(client: *mut _rfbClientRec, data: *mut *mut c_void) -> rfbBool>,
pub init: Option<unsafe extern "C" fn(client: *mut _rfbClientRec, data: *mut c_void) -> rfbBool>,
pub pseudoEncodings: *mut c_int,
pub enablePseudoEncoding: Option<unsafe extern "C" fn(client: *mut _rfbClientRec, data: *mut *mut c_void, encodingNumber: c_int) -> rfbBool>,
pub handleMessage: Option<unsafe extern "C" fn(client: *mut _rfbClientRec, data: *mut c_void, message: *const rfbClientToServerMsg) -> rfbBool>,
pub close: Option<unsafe extern "C" fn(client: *mut _rfbClientRec, data: *mut c_void)>,
pub usage: Option<unsafe extern "C" fn()>,
pub processArgument: Option<unsafe extern "C" fn(argc: c_int, argv: *mut *mut c_char) -> c_int>,
pub next: *mut _rfbProtocolExtension,
}Expand description
Protocol extension handling.
Fields
newClient: Option<unsafe extern "C" fn(client: *mut _rfbClientRec, data: *mut *mut c_void) -> rfbBool>returns FALSE if extension should be deactivated for client. if newClient == NULL, it is always deactivated.
init: Option<unsafe extern "C" fn(client: *mut _rfbClientRec, data: *mut c_void) -> rfbBool>returns FALSE if extension should be deactivated for client. if init == NULL, it stays activated.
pseudoEncodings: *mut c_intif pseudoEncodings is not NULL, it contains a 0 terminated list of the pseudo encodings handled by this extension.
enablePseudoEncoding: Option<unsafe extern "C" fn(client: *mut _rfbClientRec, data: *mut *mut c_void, encodingNumber: c_int) -> rfbBool>returns TRUE if that pseudo encoding is handled by the extension. encodingNumber==0 means “reset encodings”.
handleMessage: Option<unsafe extern "C" fn(client: *mut _rfbClientRec, data: *mut c_void, message: *const rfbClientToServerMsg) -> rfbBool>returns TRUE if message was handled
close: Option<unsafe extern "C" fn(client: *mut _rfbClientRec, data: *mut c_void)>usage: Option<unsafe extern "C" fn()>processArgument: Option<unsafe extern "C" fn(argc: c_int, argv: *mut *mut c_char) -> c_int>processArguments returns the number of handled arguments
next: *mut _rfbProtocolExtensionTrait Implementations
sourceimpl Clone for _rfbProtocolExtension
impl Clone for _rfbProtocolExtension
sourcefn clone(&self) -> _rfbProtocolExtension
fn clone(&self) -> _rfbProtocolExtension
Returns a copy of the value. Read more
1.0.0 · sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moresourceimpl Debug for _rfbProtocolExtension
impl Debug for _rfbProtocolExtension
impl Copy for _rfbProtocolExtension