Type Alias libvnc_sys::rfb::FinishedFrameBufferUpdateProc
source · pub type FinishedFrameBufferUpdateProc = Option<unsafe extern "C" fn(client: *mut _rfbClient)>;Expand description
Callback indicating that a client has completely processed an rfbFramebufferUpdate message sent by a server. This is called exactly once per each handled rfbFramebufferUpdate message. @param client The client which finished processing an rfbFramebufferUpdate
Aliased Type
enum FinishedFrameBufferUpdateProc {
None,
Some(unsafe extern "C" fn(_: *mut _rfbClient)),
}