Type Alias libvnc_sys::rfb::HandleXvpMsgProc

source ·
pub type HandleXvpMsgProc = Option<unsafe extern "C" fn(client: *mut _rfbClient, version: u8, opcode: u8)>;
Handles XVP server messages. If your application sends XVP messages to the server, you’ll want to handle the server’s XVP_FAIL and XVP_INIT responses. Define a function with this prototype and set client->HandleXvpMsg to a pointer to that function subsequent to your rfbGetClient() call. @param client The client which called the XVP message handler @param version The highest XVP extension version that the server supports @param opcode The opcode. 0 is XVP_FAIL, 1 is XVP_INIT

Aliased Type

enum HandleXvpMsgProc {
    None,
    Some(unsafe extern "C" fn(_: *mut _rfbClient, _: u8, _: u8)),
}

Variants

1.0.0

None

No value.

1.0.0

Some(unsafe extern "C" fn(_: *mut _rfbClient, _: u8, _: u8))

Some value of type T.