Type Alias libvnc_sys::rfb::SelectionChangedHookPtr

source ·
pub type SelectionChangedHookPtr = Option<unsafe extern "C" fn(_index: c_int)>;
this opens a modal select box. list is an array of strings, the end marked with a NULL. It returns the index in the list or -1 if cancelled or something else wasn’t kosher.

Aliased Type

enum SelectionChangedHookPtr {
    None,
    Some(unsafe extern "C" fn(_: i32)),
}

Variants

1.0.0

None

No value.

1.0.0

Some(unsafe extern "C" fn(_: i32))

Some value of type T.