Type Alias libvnc_sys::rfb::rfbProtocolExtension

source ·
pub type rfbProtocolExtension = _rfbProtocolExtension;
Protocol extension handling.

Aliased Type

struct rfbProtocolExtension {
    pub newClient: Option<unsafe extern "C" fn(_: *mut _rfbClientRec, _: *mut *mut c_void) -> i8>,
    pub init: Option<unsafe extern "C" fn(_: *mut _rfbClientRec, _: *mut c_void) -> i8>,
    pub pseudoEncodings: *mut i32,
    pub enablePseudoEncoding: Option<unsafe extern "C" fn(_: *mut _rfbClientRec, _: *mut *mut c_void, _: i32) -> i8>,
    pub handleMessage: Option<unsafe extern "C" fn(_: *mut _rfbClientRec, _: *mut c_void, _: *const rfbClientToServerMsg) -> i8>,
    pub close: Option<unsafe extern "C" fn(_: *mut _rfbClientRec, _: *mut c_void)>,
    pub usage: Option<unsafe extern "C" fn()>,
    pub processArgument: Option<unsafe extern "C" fn(_: i32, _: *mut *mut i8) -> i32>,
    pub next: *mut _rfbProtocolExtension,
}

Fields

newClient: Option<unsafe extern "C" fn(_: *mut _rfbClientRec, _: *mut *mut c_void) -> i8>

returns FALSE if extension should be deactivated for client. if newClient == NULL, it is always deactivated.

init: Option<unsafe extern "C" fn(_: *mut _rfbClientRec, _: *mut c_void) -> i8>

returns FALSE if extension should be deactivated for client. if init == NULL, it stays activated.

pseudoEncodings: *mut i32

if pseudoEncodings is not NULL, it contains a 0 terminated list of the pseudo encodings handled by this extension.

enablePseudoEncoding: Option<unsafe extern "C" fn(_: *mut _rfbClientRec, _: *mut *mut c_void, _: i32) -> i8>

returns TRUE if that pseudo encoding is handled by the extension. encodingNumber==0 means “reset encodings”.

handleMessage: Option<unsafe extern "C" fn(_: *mut _rfbClientRec, _: *mut c_void, _: *const rfbClientToServerMsg) -> i8>

returns TRUE if message was handled

close: Option<unsafe extern "C" fn(_: *mut _rfbClientRec, _: *mut c_void)>usage: Option<unsafe extern "C" fn()>processArgument: Option<unsafe extern "C" fn(_: i32, _: *mut *mut i8) -> i32>

processArguments returns the number of handled arguments

next: *mut _rfbProtocolExtension