Function libvnc_sys::rfb::ConnectClientToUnixSockWithTimeout
source · pub unsafe extern "C" fn ConnectClientToUnixSockWithTimeout(
sockFile: *const c_char,
timeout: c_uint
) -> c_intExpand description
Tries to connect to a Unix socket using the given timeout value. @param sockFile Path of the socket file @param timeout The time in seconds to wait for a connection @return A nonblocking socket or RFB_INVALID_SOCKET if the connection failed