Function libvnc_sys::rfb::SendKeyEvent
source · pub unsafe extern "C" fn SendKeyEvent(
client: *mut rfbClient,
key: u32,
down: rfbBool
) -> rfbBoolExpand description
Sends a key event to the server. If your application is not merely a VNC viewer (i.e. it controls the server), you’ll want to send the keys that the user presses to the server. Use this function to do that. @param client The client through which to send the key event @param key An rfbKeySym defined in rfb/keysym.h @param down true if this was a key down event, false otherwise @return true if the key event was send successfully, false otherwise