Function libvnc_sys::rfb::TextChatOpen
source · pub unsafe extern "C" fn TextChatOpen(
client: *mut rfbClient
) -> rfbBoolExpand description
Opens a text chat window on the server. @param client The client through which to send the message @return true if the window was opened successfully, false otherwise