Function libvnc_sys::rfb::TextChatSend
source · pub unsafe extern "C" fn TextChatSend(
client: *mut rfbClient,
text: *mut c_char
) -> rfbBoolExpand description
Sends a text chat message to the server. @param client The client through which to send the message @param text The text to send @return true if the text was sent successfully, false otherwise