Function libvnc_sys::rfb::rfbClientGetClientData
source · pub unsafe extern "C" fn rfbClientGetClientData(
client: *mut rfbClient,
tag: *mut c_void
) -> *mut c_voidExpand description
Returns a pointer to the client data associated with the given tag. See the the documentation for rfbClientSetClientData() for a discussion of how you can use client data. @param client The client from which to get the client data @param tag The tag which identifies the client data @return a pointer to the client data