Function libvnc_sys::rfb::rfbInitClient
source · pub unsafe extern "C" fn rfbInitClient(
client: *mut rfbClient,
argc: *mut c_int,
argv: *mut *mut c_char
) -> rfbBoolExpand description
Initializes the client. The format is {PROGRAM_NAME, [OPTIONS]…, HOST}. This function does not initialize the program name if the rfbClient’s program name is set already. The options are as follows:
| Option | Description |
|---|---|
| -listen | Listen for incoming connections. |
| -listennofork | Listen for incoming connections without forking. |
| -play | Set this client to replay a previously recorded session. |
| -encodings | Set the encodings to use. The next item in the argv array is the encodings string, consisting of comma separated encodings like 'tight,ultra,raw'. |
| -compress | Set the compression level. The next item in the argv array is the compression level as an integer. Ranges from 0 (lowest) to 9 (highest). |
| -scale | Set the scaling level. The next item in the argv array is the scaling level as an integer. The screen will be scaled down by this factor. |
| -qosdscp | Set the Quality of Service Differentiated Services Code Point (QoS DSCP). The next item in the argv array is the code point as an integer. |
| -repeaterdest | Set a VNC repeater address. The next item in the argv array is the repeater's address as a string. |
The host may include a port number (delimited by a ‘:’). @param client The client to initialize @param argc The number of arguments to the initializer @param argv The arguments to the initializer as an array of NULL terminated strings @return true if the client was initialized successfully, false otherwise.