Type Alias libvnc_sys::rfb::GotCursorShapeProc
source · pub type GotCursorShapeProc = Option<unsafe extern "C" fn(client: *mut _rfbClient, xhot: c_int, yhot: c_int, width: c_int, height: c_int, bytesPerPixel: c_int)>;Expand description
Called when a cursor shape update was received from the server. The decoded cursor shape will be in client->rcSource. It’s up to the application to do something with this, e.g. draw into a viewer’s window. If you want the server to draw the cursor into the framebuffer, be careful not to announce remote cursor support, i.e. not include rfbEncodingXCursor or rfbEncodingRichCursor in SetFormatAndEncodings().
Aliased Type
enum GotCursorShapeProc {
None,
Some(unsafe extern "C" fn(_: *mut _rfbClient, _: i32, _: i32, _: i32, _: i32, _: i32)),
}