Type Alias libvnc_sys::rfb::GotFrameBufferUpdateProc
source · pub type GotFrameBufferUpdateProc = Option<unsafe extern "C" fn(client: *mut _rfbClient, x: c_int, y: c_int, w: c_int, h: c_int)>;Expand description
Callback indicating that a rectangular area of the client’s framebuffer was updated. As a server will usually send several rects per rfbFramebufferUpdate message, this callback is usually called multiple times per rfbFramebufferUpdate message. @param client The client whose framebuffer was (partially) updated @param x The x-coordinate of the upper left corner of the updated rectangle @param y The y-coordinate of the upper left corner of the updated rectangle @param w The width of the updated rectangle @param h The heigth of the updated rectangle
Aliased Type
enum GotFrameBufferUpdateProc {
None,
Some(unsafe extern "C" fn(_: *mut _rfbClient, _: i32, _: i32, _: i32, _: i32)),
}