Type Alias libvnc_sys::rfb::HandleTextChatProc
source · pub type HandleTextChatProc = Option<unsafe extern "C" fn(client: *mut _rfbClient, value: c_int, text: *mut c_char)>;Expand description
Handles a text chat message. If your application should accept text messages from the server, define a function with this prototype and set client->HandleTextChat to a pointer to that function subsequent to your rfbGetClient() call. @param client The client which called the text chat handler @param value text length if text != NULL, or one of rfbTextChatOpen, rfbTextChatClose, rfbTextChatFinished if text == NULL @param text The text message from the server
Aliased Type
enum HandleTextChatProc {
None,
Some(unsafe extern "C" fn(_: *mut _rfbClient, _: i32, _: *mut i8)),
}