Type Alias libvnc_sys::rfb::rfbSetSingleWindowProcPtr
source · pub type rfbSetSingleWindowProcPtr = Option<unsafe extern "C" fn(cl: *mut _rfbClientRec, x: c_int, y: c_int)>;Expand description
If x==1 and y==1 then set the whole display else find the window underneath x and y and set the framebuffer to the dimensions of that window
Aliased Type
enum rfbSetSingleWindowProcPtr {
None,
Some(unsafe extern "C" fn(_: *mut _rfbClientRec, _: i32, _: i32)),
}